/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.shale.usecases.rolodex;

import javax.faces.component.html.HtmlOutputText;
import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

public class HeaderSorter extends HtmlOutputText {
    private String sortBy = null;
    private boolean sortAscending = true;
    private String ascImage = null;
    private String descImage = null;


    /**
     * <p>Sets the renderer type to "org.apache.shale.HeaderSorter".</p>
     *
     */
    public HeaderSorter() {
        setRendererType("org.apache.shale.HeaderSorter");
    }
    
    /**
     * <p>Sets the family to "org.apache.shale.Sorter".</p>
     */
    public String getFamily() {
       return "org.apache.shale.Sorter";
    }

    /**
     * <p>Returns <code>true</code> if the component was selected.</p>
     */
    public boolean wasSelected() {
        boolean selected = false;
        if ((getId() != null) && getAttributes().get("defaultSort") != null) 
            selected = (getAttributes().get("defaultSort").equals(getId()));
        return selected;
    }

    /**
     * <p>Restores the component's state.</p>
     */
    public void restoreState(FacesContext facescontext, Object obj) {
        Object[] sobj = (Object[]) obj;
        super.restoreState(facescontext, sobj[0]);
        
        sortBy = (String) sobj[1];
        ascImage = (String) sobj[2];
        descImage = (String) sobj[3];
        sortAscending = ((Boolean) sobj[4]).booleanValue();
        sobj = null;

    }

    /**
     * <p>Saves the component's state.</p>
     */
    public Object saveState(FacesContext facescontext) {

        Object aobj[] = new Object[5];
        aobj[0] = super.saveState(facescontext);
        aobj[1] = sortBy;
        aobj[2] = ascImage;
        aobj[3] = descImage;
        aobj[4] = new Boolean(sortAscending);

        return aobj;
    }

    /**
     * <p>Returns a comma delimited list of properties to sort by.  The property names 
     * are defined in the bean collection contained by the UIData model.</p>
     */
    public String getSortBy() {

        if (null != sortBy)
            return sortBy;
        ValueBinding valuebinding = getValueBinding("sortBy");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;

    }

    /**
     * <p>Sets a comma delimited list of properties to sort by.  The property names 
     * are defined in the bean collection contained by the UIData model.</p>
     */    
    public void setSortBy(String s) {
        sortBy = s;
    }

    /**
     * <p>Returns <code>true</code> if the model data is sorted in ascending order
     * defined by the <code>sortBy</code> property.</p> 
     */
    public boolean isSortAscending() {
        return sortAscending;
    }

    /**
     * <p>This setter toggles the collating sequence from ascending to descending.</p>
     */
    public void setSortAscending(boolean b) {
        sortAscending = b;
    }

    /**
     * <p>Returns the acending image resource location that is relative to the
     * context root.</p> 
     */
    public String getAscImage() {
        return ascImage;
    }

    /**
     * <p>Returns the decending image resource location that is relative to the
     * context root.</p> 
     */   
    public String getDescImage() {
        return descImage;
    }

    /**
     * <p>Sets the acending image resource location that is relative to the
     * context root.</p> 
     */
    public void setAscImage(String string) {
        ascImage = string;
    }

    /**
     * <p>Sets the decending image resource location that is relative to the
     * context root.</p> 
     */   
    public void setDescImage(String string) {
        descImage = string;
    }


}
