/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.shale.usecases.rolodex;

import javax.faces.component.UIOutput;
import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

public class WebPager extends UIOutput {
    
    private String prevPageStyleClass = null;
    private String prevImage = null;
    private String nextPageStyleClass = null;
    private String nextImage = null;
    private String captionStyleClass = null;
    private String pageLinksStyleClass = null;

    /**
     * <p>Sets the renderer type to "org.apache.shale.WebPager".</p>
     */
    public WebPager() {
        setRendererType("org.apache.shale.WebPager");
    }

    /**
     * <p>Saves the components state.</p>
     */
    public Object saveState(FacesContext facescontext) {
        Object aobj[] = new Object[5];
        aobj[0] = super.saveState(facescontext);
        aobj[1] = prevPageStyleClass;
        aobj[2] = nextPageStyleClass;
        aobj[3] = pageLinksStyleClass;
        aobj[4] = captionStyleClass;
        return ((Object) (aobj));
    }

    /**
     * <p>Restores the components state.</p>
     */
    public void restoreState(FacesContext facescontext, Object obj) {
        Object aobj[] = (Object[]) obj;
        super.restoreState(facescontext, aobj[0]);
        prevPageStyleClass = (String) aobj[1];
        nextPageStyleClass = (String) aobj[2];
        pageLinksStyleClass = (String) aobj[3];
        captionStyleClass = (String) aobj[4];
    };

    
    /**
     * <p>Returns the pager captionStyleClass attribute.</p>
     */
    public String getCaptionStyleClass() {
        if (null != captionStyleClass)
            return captionStyleClass;
        ValueBinding valuebinding = getValueBinding("captionStyleClass");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }

       
    /**
     * <p>Sets the pager captionStyleClass attribute.</p>
     */
    public void setCaptionStyleClass(String captionStyleClass) {
       this.captionStyleClass = captionStyleClass;
    }

    
    /**
     * <p>Returns the pager pageLinksStyleClass attribute.</p>
     */
    public String getPageLinksStyleClass() {
        if (null != pageLinksStyleClass)
            return pageLinksStyleClass;
        ValueBinding valuebinding = getValueBinding("pageLinksStyleClass");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }
    
   
    /**
     * <p>Sets the pager pageLinksStyleClass attribute.</p>
     */
    public void setPageLinksStyleClass(String pageLinksStyleClass) {
       this.pageLinksStyleClass = pageLinksStyleClass;
    }


    
    /**
     * <p>Returns the pager prevPageStyleClass attribute.</p>
     */
    public String getPrevPageStyleClass() {
        if (null != prevPageStyleClass)
            return prevPageStyleClass;
        ValueBinding valuebinding = getValueBinding("prevPageStyleClass");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }

    
    /**
     * <p>Sets the pager prevPageStyleClass attribute.</p>
     */
    public void setPrevPageStyleClass(String s) {
        prevPageStyleClass = s;
    }

    /**
     * <p>Returns the pager nextPageStyleClass attribute.</p>
     */
    public String getNextPageStyleClass() {
        if (null != nextPageStyleClass)
            return nextPageStyleClass;
        ValueBinding valuebinding = getValueBinding("nextPageStyleClass");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }

    /**
     * <p>Sets the pager nextPageStyleClass attribute.</p>
     */
    public void setNextPageStyleClass(String s) {
        nextPageStyleClass = s;
    }

    
    /**
     * <p>Sets the pager prevImage attribute.</p>
     */
    public void setPrevImage(String s) {
        prevImage = s;
    }

    /**
     * <p>Returns the pager prevImage attribute.</p>
     */
    public String getPrevImage() {
        if (null != prevImage)
            return prevImage;
        ValueBinding valuebinding = getValueBinding("prevImage");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }
   
    /**
     * <p>Sets the pager nextImage attribute.</p>
     */
    public void setNextImage(String s) {
        nextImage = s;
    }

    /**
     * <p>Returns the pager nextImage attribute.</p>
     */
    public String getNextImage() {
        if (null != nextImage)
            return nextImage;
        ValueBinding valuebinding = getValueBinding("nextImage");
        if (valuebinding != null)
            return (String) valuebinding.getValue(getFacesContext());
        else
            return null;
    }
    
      
    
    /**
     * <p>Returns the component's family to "org.apache.shale.Pager".</p>
     */
    public String getFamily() {
        return "org.apache.shale.Pager";
    }

    /**
     * <p>The pager component renders children.</p>
     */
    public boolean getRendersChildren() {
        return true;
    }
}